# "on_off foo" wil turn into "ON" or "OFF"
%define on_off() %{expand:%%{?with_%{1}:ON}%%{!?with_%{1}:OFF}}

%define _with_sys_assert on
%bcond_with doc
%bcond_with core_dump
%bcond_with sys_assert

Name:      crash-worker
Summary:    Crash-manager
Version:    0.3.0
Release:    1
Group:      Framework/system
License:    Apache-2.0 and PD
Source0:    %{name}-%{version}.tar.gz
Source1001:    crash-worker.manifest
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(libsmack)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(iniparser)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  cmake
%if %{with sys_assert}
BuildRequires:  pkgconfig(libunwind)
%endif
BuildRequires:  libelf-devel libelf
BuildRequires:  libebl-devel libebl
BuildRequires:  libdw-devel libdw
%ifarch %{arm}
BuildRequires:  pkgconfig(libunwind-ptrace)
%endif
%if %{with doc}
BuildRequires:  doxygen
%endif

Requires(post): coreutils
Requires(post): tar
Requires(post): gzip
Requires: zip
# If you need support for core dump files (see building below),
# you should add this dependency
# Requires: libebl

%description
crash-manager

%if %{with doc}
%package doc
Summary:       Documentation package for crash-worker
Group:         Framework/System

%description doc
This package provides development documentation for crash-worker.
%endif

%prep
%setup -q

#Path to store logs and coredump files
%define crash_root_path %{TZ_SYS_CRASH_ROOT}
%define crash_path      %{TZ_SYS_CRASH}
%define crash_temp      %{crash_root_path}/temp

#Path for log_dump module
%define crash_all_log   %{TZ_SYS_ALLLOGS}
%define crash_dump_gen  %{TZ_SYS_DUMPGEN}

%define upgrade_script_path %{TZ_SYS_RO_SHARE}/upgrade/scripts

%build
cp %{SOURCE1001} .

export CFLAGS+=" -Werror"

%ifarch %{arm} aarch64
	%define ARCH arm
%else
	%define ARCH x86
%endif

%ifarch %{arm} %ix86
	%define ARCH_BIT 32
%else
	%define ARCH_BIT 64
%endif

%cmake . \
	   -DCMAKE_INSTALL_PREFIX=%{_prefix} \
	   -DTMP_FILES_DIR=%{_sysconfdir}/tmpfiles.d \
	   -DARCH=%{ARCH} \
	   -DARCH_BIT=%{ARCH_BIT} \
	   -DTZ_SYS_ETC=%{TZ_SYS_ETC} \
	   -DTZ_SYS_BIN=%{TZ_SYS_BIN} \
	   -DCRASH_ROOT_PATH=%{crash_root_path} \
	   -DCRASH_PATH=%{crash_path} \
	   -DCRASH_TEMP=%{crash_temp} \
	   -DCRASH_PIPE_PATH=%{_libexecdir}/crash-pipe \
	   -DCRASH_STACK_PATH=%{_libexecdir}/crash-stack \
	   -DSYS_ASSERT=%{on_off sys_assert} \
	   -DUPGRADE_SCRIPT_PATH=%{upgrade_script_path} \
	   -DWITH_CORE_DUMP=%{on_off core_dump}

make %{?jobs:-j%jobs}
%if %{with doc}
make doc
%endif

%install
rm -rf %{buildroot}
%make_install
mkdir -p %{buildroot}%{crash_root_path}
mkdir -p %{buildroot}%{crash_path}
mkdir -p %{buildroot}%{crash_temp}

# log_dump dir
mkdir -p %{buildroot}%{crash_all_log}
mkdir -p %{buildroot}%{crash_dump_gen}
cp dump_scripts/* %{buildroot}%{crash_dump_gen}
chmod 755 %{buildroot}%{crash_dump_gen}/*

%post
%if %{with sys_assert}
if [ ! -d /.build ]; then
	orig="%{_libdir}/libsys-assert.so"
	pattern=$(echo $orig | sed -e 's|/|\\/|g')
	ret=$(sed -n "/${pattern}/p"  %{_sysconfdir}/ld.so.preload)
	if [ -z "$ret" ]; then
		echo "%{_libdir}/libsys-assert.so" >> %{_sysconfdir}/ld.so.preload
	fi
	chmod 644 %{_sysconfdir}/ld.so.preload
fi

/sbin/ldconfig
%endif

/usr/bin/chsmack -a "System::Shared" -t %{crash_path}
/usr/bin/chsmack -a "System::Shared" -t %{crash_temp}
/usr/bin/chsmack -a "System::Shared" -t %{crash_dump_gen}
/usr/bin/chsmack -a "System::Shared" -t %{crash_dump_gen}/module.d
/usr/bin/chsmack -a "_"  %{crash_dump_gen}/module.d/*

%postun
%if %{with sys_assert}
orig="%{_libdir}/libsys-assert.so"
pattern=$(echo $orig | sed -e 's|/|\\/|g')
sed -i "/${pattern}/D" %{_sysconfdir}/ld.so.preload
/sbin/ldconfig
%endif

%files
%license LICENSE
%manifest crash-worker.manifest
%defattr(-,system,system,-)
%dir %{crash_root_path}
%dir %{crash_path}
%dir %{crash_temp}
%dir %{crash_all_log}
%{crash_dump_gen}/*
%attr(0755,root,root) %{_bindir}/*
%attr(0644,root,system) %{_unitdir}/tizen-debug-on.service
%attr(0644,root,system) %{_unitdir}/tizen-debug-off.service
%{TZ_SYS_ETC}/crash-manager.conf
%{_prefix}/lib/sysctl.d/99-crash-manager.conf
%{_datadir}/dbus-1/system-services/org.tizen.system.crash.service

%if %{with sys_assert}
%{_libdir}/libsys-assert.so
%{_sysconfdir}/tmpfiles.d/sys-assert.conf
%endif

%{_libexecdir}/crash-pipe
%{_libexecdir}/crash-stack

#upgrade script
%attr(-,root,root) %{upgrade_script_path}/500.crash-manager-upgrade.sh

%if %{with doc}
%files doc
%{_datadir}/doc/crash-worker
%endif
